==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/web-util/src/forms/InputSelectOne.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { TranslatedString } from "@gnu-taler/taler-util";
import * as tests from "@gnu-taler/web-util/testing";
import {
  FlexibleForm,
  DefaultForm as TestedComponent,
} from "./DefaultForm.js";

export default {
  title: "Input Select One",
};

export namespace Simplest {
  export interface Form {
    comment: string;
  }
}

type TargetObject = {
  things: string;
}
const initial: TargetObject = {
  things: "one"
}

const form: FlexibleForm<TargetObject> = {
  design: [{
    title: "this is a simple form" as TranslatedString,
    fields: [{
      type: "selectOne",
      props: {
        label: "label of the field" as TranslatedString,
        name: "things",
        placeholder: "search..." as TranslatedString,
        choices: [{
          label: "one label" as TranslatedString,
          value: "one"
        }, {
          label: "two label" as TranslatedString,
          value: "two"
        }, {
          label: "five label" as TranslatedString,
          value: "five"
        }]
      },
    }]
  }]
}

export const SimpleComment = tests.createExample(TestedComponent, { initial, form });

==> taler-wallet-v0.12.7.tar.gz: taler-wallet-v0.12.7/packages/web-util/src/forms/InputSelectOne.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { TranslatedString } from "@gnu-taler/taler-util";
import * as tests from "@gnu-taler/web-util/testing";
import {
  FlexibleForm_Deprecated,
  DefaultForm as TestedComponent,
} from "./DefaultForm.js";

export default {
  title: "Input Select One",
};

export namespace Simplest {
  export interface Form {
    comment: string;
  }
}

type TargetObject = {
  things: string;
}
const initial: TargetObject = {
  things: "one"
}

const form: FlexibleForm_Deprecated<TargetObject> = {
  design: [{
    title: "this is a simple form" as TranslatedString,
    fields: [{
      type: "selectOne",
      properties: {
        label: "label of the field" as TranslatedString,
        name: "things",
        placeholder: "search..." as TranslatedString,
        choices: [{
          label: "one label" as TranslatedString,
          value: "one"
        }, {
          label: "two label" as TranslatedString,
          value: "two"
        }, {
          label: "five label" as TranslatedString,
          value: "five"
        }]
      },
    }]
  }]
}

export const SimpleComment = tests.createExample(TestedComponent, { initial, form });
